@@ -110,9 +110,8 @@ $.fn.editable = function(options){
 $.editableFactory = {
 	'text': {
 		toEditable: function($this,options){
-			console.log($this.data('editable.current').replace(/[\t\r\n]/g, '').replace(/\s+/g, ' '));
 			$('<input/>').appendTo($this)
-						 .val($this.data('editable.current').replace(/[\t\r\n]/g, '').replace(/\s+/g, ' '));
+						 .val($this.data('editable.current'));
 		},
 		getValue: function($this,options){
 			return $this.children().val();
@@ -216,16 +215,26 @@ HUB.Contribute = {
 				}
 			});
 		}
-
+		
+		/*if ($('#authors').length > 0) {
+			console.log($('#authors').parent());
+			var container = $('#authors').parent();
+			var src = $('#authors').attr('src').replace('tmpl=component', 'no_html=1');
+			$.get(src, {}, function(data){
+				container.html(data);
+			});
+		}*/
+		
 		$('.ftitle').editable({
 			type:'text',
 			submit:'save',
 			cancel:'cancel',
 			editClass:'resultItem',
 			onSubmit: function() {
-				$.get('index.php?option=com_tools&controller=attachments&task=rename&no_html=1&id=' + this.attr('data-id') + '&name='+this.text());
+				$.get('index.php?option=com_contribute&controller=attachments&task=rename&no_html=1&id='+$('#pid').val()+'&name='+content.current);
 			}
 		});
+		//new eip($$('.ftitle'), 'index.php', {option: 'com_contribute', task: 'rename', no_html: 1});
 	}
 }
 
